@@ -27,20 +27,20 @@
 
 #include "libgossip-marshal.h"
 
+#include "gossip-utils.h"
 #include "gossip-chatroom-manager.h"
 #include "gossip-protocol.h"
 
 #define CHATROOMS_XML_FILENAME "chatrooms.xml"
 #define CHATROOMS_DTD_FILENAME "gossip-chatroom.dtd"
 
-#define d(x)
+#define DEBUG_MSG(x)
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");  */
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_CHATROOM_MANAGER, GossipChatroomManagerPriv))
 
-
 typedef struct _GossipChatroomManagerPriv GossipChatroomManagerPriv;
 
-
 struct _GossipChatroomManagerPriv {
 	GossipAccountManager *account_manager;
 	GossipSession        *session;
@@ -53,7 +53,6 @@ struct _GossipChatroomManagerPriv {
 	gchar                *default_name;
 };
 
-
 static void     chatroom_manager_finalize              (GObject                  *object);
 static void     chatroom_manager_chatroom_enabled_cb   (GossipChatroom           *chatroom,
 							GParamSpec               *arg1,
@@ -71,22 +70,19 @@ static void     chatroom_manager_protocol_connected_cb (GossipSession
 							GossipProtocol           *protocol,
 							GossipChatroomManager    *manager);
 
-
 enum {
 	CHATROOM_ADDED,
 	CHATROOM_REMOVED, 
 	CHATROOM_ENABLED,
-	CHATROOM_AUTO_CONNECTED,
+	CHATROOM_AUTO_CONNECT_UPDATE,
 	NEW_DEFAULT,
 	LAST_SIGNAL
 };
 
 static guint  signals[LAST_SIGNAL] = {0};
 
-
 G_DEFINE_TYPE (GossipChatroomManager, gossip_chatroom_manager, G_TYPE_OBJECT);
 
-
 static void
 gossip_chatroom_manager_class_init (GossipChatroomManagerClass *klass)
 {
@@ -121,8 +117,8 @@ gossip_chatroom_manager_class_init (GossipChatroomManagerClass *klass)
 			      libgossip_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
 			      1, GOSSIP_TYPE_CHATROOM);
-        signals[CHATROOM_AUTO_CONNECTED] = 
-		g_signal_new ("chatroom-auto-connected",
+        signals[CHATROOM_AUTO_CONNECT_UPDATE] = 
+		g_signal_new ("chatroom-auto-connect-update",
 			      G_TYPE_FROM_CLASS (klass),
                               G_SIGNAL_RUN_LAST,
 			      0, 
@@ -238,7 +234,7 @@ gossip_chatroom_manager_add (GossipChatroomManager *manager,
 		type = gossip_chatroom_get_type (chatroom);
 		name = gossip_chatroom_get_name (chatroom);
 
-		d(g_print ("Chatroom Manager: Adding %s%s chatroom with name:'%s'\n", 
+		DEBUG_MSG (("ChatroomManager: Adding %s%s chatroom with name:'%s'", 
 			   gossip_chatroom_get_auto_connect (chatroom) ? "connecting on startup " : "", 
 			   gossip_chatroom_get_type_as_str (type), 
 			   name));
@@ -274,7 +270,7 @@ gossip_chatroom_manager_remove (GossipChatroomManager *manager,
 
 	priv = GET_PRIV (manager);
 
- 	d(g_print ("Chatroom Manager: Removing chatroom with name:'%s'\n",  
+ 	DEBUG_MSG (("ChatroomManager: Removing chatroom with name:'%s'",  
  		   gossip_chatroom_get_name (chatroom)));
 
 	g_signal_handlers_disconnect_by_func (chatroom, 
@@ -421,7 +417,7 @@ gossip_chatroom_manager_set_default (GossipChatroomManager *manager,
 
 	priv = GET_PRIV (manager);
 	
- 	d(g_print ("Chatroom Manager: Setting default chatroom with name:'%s'\n",  
+ 	DEBUG_MSG (("ChatroomManager: Setting default chatroom with name:'%s'",  
  		   gossip_chatroom_get_name (chatroom))); 
 
 	name = gossip_chatroom_get_name (chatroom);
@@ -470,7 +466,7 @@ gossip_chatroom_manager_store (GossipChatroomManager *manager)
 {
 	g_return_val_if_fail (GOSSIP_IS_CHATROOM_MANAGER (manager), FALSE);
 
- 	d(g_print ("Chatroom Manager: Saving chatrooms\n"));  
+ 	DEBUG_MSG (("ChatroomManager: Saving chatrooms"));  
 	
 	return chatroom_manager_file_save (manager);
 }
@@ -641,20 +637,20 @@ chatroom_manager_file_parse (GossipChatroomManager *manager,
 
 	priv = GET_PRIV (manager);
 	
-	d(g_print ("Chatroom Manager: Attempting to parse file:'%s'...\n", filename));
+	DEBUG_MSG (("ChatroomManager: Attempting to parse file:'%s'...", filename));
 
  	ctxt = xmlNewParserCtxt ();
 
 	/* Parse and validate the file. */
-	doc = xmlCtxtReadFile (ctxt, filename, NULL, XML_PARSE_DTDVALID);	
+	doc = xmlCtxtReadFile (ctxt, filename, NULL, 0);	
 	if (!doc) {
 		g_warning ("Failed to parse file:'%s'", filename);
 		xmlFreeParserCtxt (ctxt);
 		return FALSE;
 	}
-
-	if (!ctxt->valid) {
-		g_warning ("Failed to validate file:'%s'",  filename);
+	
+	if (!gossip_utils_xml_validate (doc, CHATROOMS_DTD_FILENAME)) {
+		g_warning ("Failed to validate file:'%s'", filename);
 		xmlFreeDoc(doc);
 		xmlFreeParserCtxt (ctxt);
 		return FALSE;
@@ -680,10 +676,10 @@ chatroom_manager_file_parse (GossipChatroomManager *manager,
 		node = node->next;
 	}
 	
-	d(g_print ("Chatroom Manager: Parsed %d chatrooms\n", 
+	DEBUG_MSG (("ChatroomManager: Parsed %d chatrooms", 
 		   g_list_length (priv->chatrooms)));
 
-	d(g_print ("Chatroom Manager: Default chatroom is:'%s'\n", 
+	DEBUG_MSG (("ChatroomManager: Default chatroom is:'%s'", 
 		   priv->default_name));
 	
 	xmlFreeDoc(doc);
@@ -723,19 +719,19 @@ chatroom_manager_file_save (GossipChatroomManager *manager)
 
 	dtd_file = g_build_filename (DTDDIR, CHATROOMS_DTD_FILENAME, NULL);
 
-	doc = xmlNewDoc (BAD_CAST "1.0");
-	root = xmlNewNode (NULL, BAD_CAST "chatrooms");
+	doc = xmlNewDoc ("1.0");
+	root = xmlNewNode (NULL, "chatrooms");
 	xmlDocSetRootElement (doc, root);
 
-	dtd = xmlCreateIntSubset (doc, BAD_CAST "chatrooms", NULL, BAD_CAST dtd_file);
+	dtd = xmlCreateIntSubset (doc, "chatrooms", NULL, dtd_file);
 
 	if (!priv->default_name) {
 		priv->default_name = g_strdup ("Default");
 	}
 	
-	xmlNewChild (root, NULL, 
-		     BAD_CAST "default", 
-		     BAD_CAST priv->default_name);
+	xmlNewTextChild (root, NULL, 
+			 "default", 
+			 priv->default_name);
 
 	chatrooms = gossip_chatroom_manager_get_chatrooms (manager, NULL);
 
@@ -754,27 +750,27 @@ chatroom_manager_file_save (GossipChatroomManager *manager)
 			break;
 		}
 	
-		node = xmlNewChild (root, NULL, BAD_CAST "chatroom", NULL);
-		xmlNewChild (node, NULL, BAD_CAST "type", BAD_CAST type);
-		xmlNewChild (node, NULL, BAD_CAST "name", BAD_CAST gossip_chatroom_get_name (chatroom));
-		xmlNewChild (node, NULL, BAD_CAST "nick", BAD_CAST gossip_chatroom_get_nick (chatroom));
+		node = xmlNewChild (root, NULL, "chatroom", NULL);
+		xmlNewChild (node, NULL, "type", type);
+		xmlNewTextChild (node, NULL, "name", gossip_chatroom_get_name (chatroom));
+		xmlNewTextChild (node, NULL, "nick", gossip_chatroom_get_nick (chatroom));
 
-		xmlNewChild (node, NULL, BAD_CAST "server", BAD_CAST gossip_chatroom_get_server (chatroom));
-		xmlNewChild (node, NULL, BAD_CAST "room", BAD_CAST gossip_chatroom_get_room (chatroom));
+		xmlNewTextChild (node, NULL, "server", gossip_chatroom_get_server (chatroom));
+		xmlNewTextChild (node, NULL, "room", gossip_chatroom_get_room (chatroom));
 
-		xmlNewChild (node, NULL, BAD_CAST "password", BAD_CAST gossip_chatroom_get_password (chatroom));
-		xmlNewChild (node, NULL, BAD_CAST "auto_connect", BAD_CAST (gossip_chatroom_get_auto_connect (chatroom) ? "yes" : "no"));
+		xmlNewTextChild (node, NULL, "password", gossip_chatroom_get_password (chatroom));
+		xmlNewChild (node, NULL, "auto_connect", gossip_chatroom_get_auto_connect (chatroom) ? "yes" : "no");
 
 		account = gossip_chatroom_get_account (chatroom);
 		if (account) {
-			xmlNewChild (node, NULL, BAD_CAST "account", BAD_CAST gossip_account_get_name (account));
+			xmlNewTextChild (node, NULL, "account", gossip_account_get_name (account));
 			g_object_unref (account);
 		}
 
 		g_free (type);
 	}
 
-	d(g_print ("Chatroom Manager: Saving file:'%s'\n", xml_file));
+	DEBUG_MSG (("ChatroomManager: Saving file:'%s'", xml_file));
 	xmlSaveFormatFileEnc (xml_file, doc, "utf-8", 1);
 	xmlFreeDoc (doc);
 
@@ -793,7 +789,8 @@ chatroom_manager_join_cb (GossipChatroomProvider   *provider,
 			  GossipChatroomId          id,
 			  GossipChatroomManager    *manager)
 {
-	g_signal_emit (manager, signals[CHATROOM_AUTO_CONNECTED], 0, 
+	g_print ("result:%d\n", result);
+	g_signal_emit (manager, signals[CHATROOM_AUTO_CONNECT_UPDATE], 0, 
 		       provider, id, result);
 }
 
@@ -810,7 +807,8 @@ chatroom_manager_protocol_connected_cb (GossipSession         *session,
 
 	priv = GET_PRIV (manager);
 	
-	d(g_print ("Chatroom Manager: Account:'%s' connected, checking chatroom auto connects.\n",
+	DEBUG_MSG (("ChatroomManager: Account:'%s' connected, "
+		    "checking chatroom auto connects.",
 		   gossip_account_get_name (account)));
 
 	chatrooms = gossip_chatroom_manager_get_chatrooms (manager, account);
