@@ -42,11 +42,10 @@
 #include "gossip-jabber.h"
 #include "gossip-jabber-private.h"
 
-#define d(x)
+#define DEBUG_MSG(x)
+/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n");  */
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-						    GOSSIP_TYPE_JABBER, \
-						    GossipJabberPriv))
+#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_JABBER, GossipJabberPriv))
 
 #define XMPP_VERSION_XMLNS  "jabber:iq:version"
 #define XMPP_ROSTER_XMLNS   "jabber:iq:roster"
@@ -125,8 +124,7 @@ static gboolean         jabber_logout_contact_foreach       (gpointer
 static GError *         jabber_error_create                 (GossipProtocolError      code,
 							     const gchar             *reason);
 static void             jabber_error                        (GossipProtocol          *protocol,
-							     GossipProtocolError      code,
-							     const gchar             *reason);
+							     GossipProtocolError      code);
 static void             jabber_connection_open_cb           (LmConnection            *connection,
 							     gboolean                 result,
 							     GossipJabber            *jabber);
@@ -409,7 +407,7 @@ jabber_setup (GossipProtocol *protocol,
  	GossipJabber     *jabber;
  	GossipJabberPriv *priv;
  	LmMessageHandler *handler;
-	const gchar      *id;
+	gchar            *id;
 	GossipJID        *jid;
 	
  	g_return_if_fail (GOSSIP_IS_JABBER (protocol));
@@ -422,14 +420,17 @@ jabber_setup (GossipProtocol *protocol,
  
  	priv->contact = gossip_contact_new (GOSSIP_CONTACT_TYPE_USER,
 					    priv->account);
- 
-	id = gossip_account_get_id (account);
+	
+	id = g_strdup_printf ("%s/%s", 
+			      gossip_account_get_id (account),
+			      gossip_account_get_resource (account));
 	jid = gossip_jid_new (id);
 
 	g_object_set (priv->contact,
 		      "id", id,          /* we need FULL JID here */
 		      "name", id,
 		      NULL);
+	g_free (id);
 
 	priv->connection = lm_connection_new (gossip_account_get_server (account));
 
@@ -492,7 +493,7 @@ jabber_setup_connection (GossipJabber *jabber)
 	if (gossip_account_get_use_ssl (priv->account)) {
 		LmSSL *ssl;
 
-		d(g_print ("Protocol: Using SSL\n"));
+		DEBUG_MSG (("Protocol: Using SSL"));
 
 		ssl = lm_ssl_new (NULL,
 				  (LmSSLFunction) jabber_ssl_status_cb,
@@ -506,7 +507,7 @@ jabber_setup_connection (GossipJabber *jabber)
 	}
 
 	if (gossip_account_get_use_proxy (priv->account)) {
-		d(g_print ("Protocol: Using proxy\n"));
+		DEBUG_MSG (("Protocol: Using proxy"));
 
 		jabber_set_proxy (priv->connection);
 	} else {
@@ -532,7 +533,7 @@ jabber_login (GossipProtocol *protocol)
 	jabber = GOSSIP_JABBER (protocol);
 	priv = GET_PRIV (jabber);
 
-	d(g_print ("Protocol: Logging in Jabber\n"));
+	DEBUG_MSG (("Protocol: Logging in Jabber"));
 
 	priv->presence = gossip_presence_new ();
 	gossip_presence_set_state (priv->presence, 
@@ -542,9 +543,7 @@ jabber_login (GossipProtocol *protocol)
 	jabber_setup_connection (jabber);
 
 	if (!priv->connection) {
-		jabber_error (GOSSIP_PROTOCOL (jabber), 
-			      GOSSIP_PROTOCOL_NO_CONNECTION,
-			      _("Could not open connection"));
+		jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_NO_CONNECTION);
 		return;
 	}
 
@@ -569,9 +568,7 @@ jabber_login (GossipProtocol *protocol)
 	if (error->code == 1 && 
 	    strcmp (error->message, "getaddrinfo() failed") == 0) {
 		/* host lookup failed */
-		jabber_error (GOSSIP_PROTOCOL (jabber), 
-			      GOSSIP_PROTOCOL_NO_SUCH_HOST,
-			      _("Could not find the server you wanted to use"));
+		jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_NO_SUCH_HOST);
 	}
 
 	g_error_free (error);
@@ -586,9 +583,7 @@ jabber_login_timeout_cb (GossipJabber *jabber)
 
 	priv->connection_timeout_id = 0;
 
-	jabber_error (GOSSIP_PROTOCOL (jabber), 
-		      GOSSIP_PROTOCOL_TIMED_OUT,
-		      _("Connection to the server failed."));
+	jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_TIMED_OUT);
 
 	return FALSE;
 }
@@ -643,20 +638,22 @@ jabber_error_create (GossipProtocolError  code,
 
 static void
 jabber_error (GossipProtocol      *protocol, 
-	      GossipProtocolError  code,
-	      const gchar         *reason)
+	      GossipProtocolError  code)
 {
 	GossipJabber     *jabber;
 	GossipJabberPriv *priv;
 	GError           *error;
+	const gchar      *message;
 
 	g_return_if_fail (GOSSIP_IS_JABBER (protocol));
-	g_return_if_fail (reason != NULL);
 
 	jabber = GOSSIP_JABBER (protocol);
 	priv = GET_PRIV (jabber);
 
-	error = jabber_error_create (code, reason);
+	message = gossip_protocol_error_to_string (code);
+	DEBUG_MSG (("Protocol: Error:%d->'%s'", code, message));
+
+	error = jabber_error_create (code, message);
 	g_signal_emit_by_name (protocol, "error", priv->account, error);
  	g_error_free (error); 
 }
@@ -688,13 +685,11 @@ jabber_connection_open_cb (LmConnection *connection,
 	}
 
 	if (result == FALSE) {
-		jabber_error (GOSSIP_PROTOCOL (jabber), 
-			      GOSSIP_PROTOCOL_NO_CONNECTION,
-			      _("Could not open connection"));
+		jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_NO_CONNECTION);
 		return;
 	}
 
-	d(g_print ("Protocol: Connection open!\n"));
+	DEBUG_MSG (("Protocol: Connection open!"));
 
 	account = priv->account;
 	account_password = gossip_account_get_password (account);
@@ -709,12 +704,19 @@ jabber_connection_open_cb (LmConnection *connection,
 	 
 	/* FIXME: Decide on Resource */
 	jid_str = gossip_account_get_id (account);
+	DEBUG_MSG (("Protocol: Attempting to use JabberID:'%s'", jid_str));
 
 	id = gossip_jid_string_get_part_name (jid_str);
-	resource = gossip_jid_string_get_part_resource (jid_str);
+	resource = gossip_account_get_resource (account);
+
+	if (!resource) {
+		DEBUG_MSG (("Protocol: JabberID:'%s' is invalid, there is no resource.", jid_str));
+
+		jabber_logout (GOSSIP_PROTOCOL (jabber));
+		jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_INVALID_USER);
+		return;
+	}
 
-	d(g_print ("Protocol: Using JabberID:'%s'\n", jid_str));
-	
 	lm_connection_authenticate (priv->connection,
 				    id,
 				    password, 
@@ -738,13 +740,11 @@ jabber_connection_auth_cb (LmConnection *connection,
 	priv = GET_PRIV (jabber);
 	
 	if (result == FALSE) {
-		jabber_error (GOSSIP_PROTOCOL (jabber), 
-			      GOSSIP_PROTOCOL_AUTH_FAILED,
-			      _("Authentication failed"));
+		jabber_error (GOSSIP_PROTOCOL (jabber), GOSSIP_PROTOCOL_AUTH_FAILED);
 		return;
 	}
 
-	d(g_print ("Protocol: Connection logged in!\n"));
+	DEBUG_MSG (("Protocol: Connection logged in!"));
 
 	/* Request roster */
 	m = lm_message_new_with_sub_type (NULL,
@@ -857,7 +857,7 @@ jabber_ssl_status_cb (LmConnection *connection,
 		break;
 	}
 
-	d(g_print ("Protocol: %s\n", str));
+	DEBUG_MSG (("Protocol: %s", str));
 
 	return LM_SSL_RESPONSE_CONTINUE;
 }
@@ -915,7 +915,7 @@ jabber_register_account (GossipProtocol          *protocol,
 	g_return_if_fail (GOSSIP_IS_JABBER (protocol));
 	g_return_if_fail (callback != NULL);
 
-	d(g_print ("Protocol: Registering with Jabber server...\n"));
+	DEBUG_MSG (("Protocol: Registering with Jabber server..."));
 
 	jabber = GOSSIP_JABBER (protocol);
 	priv = GET_PRIV (jabber);
@@ -945,7 +945,7 @@ error:
 	error_message = gossip_protocol_error_to_string (error_code);
 	error = jabber_error_create (error_code, error_message);
 
-	d(g_print ("Protocol: %s\n", error_message));
+	DEBUG_MSG (("Protocol: %s", error_message));
 	
 	if (callback) {
 		(callback) (GOSSIP_RESULT_ERROR_REGISTRATION, 
@@ -965,7 +965,7 @@ jabber_register_cancel (GossipProtocol *protocol)
 
 	g_return_if_fail (GOSSIP_IS_JABBER (protocol));
 
-	d(g_print ("Protocol: Canceling registration with Jabber server...\n"));
+	DEBUG_MSG (("Protocol: Canceling registration with Jabber server..."));
 
 	jabber = GOSSIP_JABBER (protocol);
 	priv = GET_PRIV (jabber);
@@ -984,6 +984,8 @@ jabber_register_connection_open_cb (LmConnection *connection,
 	LmMessage        *m;
 	LmMessageNode    *node;
 	const gchar      *error_message = NULL;
+	const gchar      *id;
+	gchar            *username;
 	gboolean          ok = FALSE;
 
 	priv = GET_PRIV (ra->jabber);
@@ -1000,7 +1002,7 @@ jabber_register_connection_open_cb (LmConnection *connection,
 		error = jabber_error_create (GOSSIP_PROTOCOL_NO_CONNECTION,
 					     error_message);
 
-		d(g_print ("Protocol: %s\n", error_message));
+		DEBUG_MSG (("Protocol: %s", error_message));
 
 		if (ra->callback) {
 			(ra->callback) (GOSSIP_RESULT_ERROR_REGISTRATION, 
@@ -1013,7 +1015,7 @@ jabber_register_connection_open_cb (LmConnection *connection,
 		return;
 	}
  
-	d(g_print ("Protocol: Connection open!\n"));
+	DEBUG_MSG (("Protocol: Connection open!"));
 
 	ra->message_handler = lm_message_handler_new ((LmHandleMessageFunction) 
 						      jabber_register_message_handler,
@@ -1029,7 +1031,11 @@ jabber_register_connection_open_cb (LmConnection *connection,
 
         lm_message_node_set_attribute (node, "xmlns", XMPP_REGISTER_XMLNS);
 	
-	lm_message_node_add_child (node, "username", gossip_account_get_id (priv->account));
+	id = gossip_account_get_id (priv->account);
+	username = gossip_jid_string_get_part_name (id);
+	lm_message_node_add_child (node, "username", username);
+	g_free (username);
+
 	lm_message_node_add_child (node, "password", gossip_account_get_password (priv->account));
 
         ok = lm_connection_send_with_reply (connection, m, 
@@ -1044,7 +1050,7 @@ jabber_register_connection_open_cb (LmConnection *connection,
 		error = jabber_error_create (GOSSIP_PROTOCOL_SPECIFIC_ERROR,
 					     error_message);
 
-		d(g_print ("Protocol: %s\n", error_message));
+		DEBUG_MSG (("Protocol: %s", error_message));
 
 		if (ra->callback) {
 			(ra->callback) (GOSSIP_RESULT_ERROR_REGISTRATION, 
@@ -1057,7 +1063,7 @@ jabber_register_connection_open_cb (LmConnection *connection,
 		return;
 	}
 
-	d(g_print ("Protocol: Sent registration details\n"));
+	DEBUG_MSG (("Protocol: Sent registration details"));
 }
 
 static LmHandlerResult
@@ -1126,10 +1132,10 @@ jabber_register_message_handler (LmMessageHandler *handler,
 		error = jabber_error_create (error_code,
 					     error_message);
 
-		d(g_print ("Protocol: Registration failed with error:%s->'%s'\n",
+		DEBUG_MSG (("Protocol: Registration failed with error:%s->'%s'",
 			   error_code_str, error_message));	
 	} else {
-		d(g_print ("Protocol: Registration success\n"));
+		DEBUG_MSG (("Protocol: Registration success"));
 	}
 
 	if (ra->callback) {
@@ -1179,7 +1185,7 @@ jabber_is_valid_username (GossipProtocol *protocol,
 	jabber = GOSSIP_JABBER (protocol);
 	priv = GET_PRIV (jabber);
 
-	return gossip_jid_string_is_valid (username, TRUE);
+	return gossip_jid_string_is_valid (username, FALSE);
 }
 
 static gboolean
@@ -1191,7 +1197,7 @@ jabber_is_ssl_supported (GossipProtocol *protocol)
 static const gchar *
 jabber_get_example_username (GossipProtocol *protocol)
 {
-	return "user@jabber.org/laptop";
+	return "user@jabber.org";
 }
 
 static gchar *
@@ -1269,7 +1275,7 @@ jabber_send_message (GossipProtocol *protocol,
 		jid_str = g_strdup (recipient_id);
 	}
 
-	d(g_print ("Protocol: Sending message to: '%s'\n", jid_str));
+	DEBUG_MSG (("Protocol: Sending message to: '%s'", jid_str));
 	
 	m = lm_message_new_with_sub_type (jid_str,
 					  LM_MESSAGE_TYPE_MESSAGE,
@@ -1316,7 +1322,7 @@ jabber_send_composing (GossipProtocol *protocol,
 
 	contact_id = gossip_contact_get_id (contact);
 
-	d(g_print ("Protocol: Sending %s to contact:'%s'\n", 
+	DEBUG_MSG (("Protocol: Sending %s to contact:'%s'", 
 		   typing ? "composing" : "not composing",
 		   contact_id));
 	
@@ -1404,7 +1410,7 @@ jabber_set_presence (GossipProtocol *protocol,
 		break;
 	}
 
-	d(g_print ("Protocol: Setting presence to:'%s', status:'%s', priority:'%s'\n", 
+	DEBUG_MSG (("Protocol: Setting presence to:'%s', status:'%s', priority:'%s'", 
 		   show ? show : "available", 
 		   status ? status : "",
 		   priority));
@@ -1437,7 +1443,7 @@ jabber_set_subscription (GossipProtocol *protocol,
 
 	jabber = GOSSIP_JABBER (protocol);
 
-	d(g_print ("Protocol: Settting subscription for contact:'%s' as %s\n", 
+	DEBUG_MSG (("Protocol: Settting subscription for contact:'%s' as %s", 
 		   gossip_contact_get_id (contact),
 		   subscribed ? "subscribed" : "unsubscribed"));
 
@@ -1988,7 +1994,7 @@ jabber_message_handler (LmMessageHandler *handler,
 
 	priv = GET_PRIV (jabber);
 	
-	d(g_print ("Protocol: New message from: %s\n", 
+	DEBUG_MSG (("Protocol: New message from: %s", 
 		   lm_message_node_get_attribute (m->node, "from")));
 
 	switch (lm_message_get_sub_type (m)) {
@@ -2068,7 +2074,7 @@ jabber_presence_handler (LmMessageHandler *handler,
 	priv = GET_PRIV (jabber);
 
 	from = lm_message_node_get_attribute (m->node, "from");
-        d(g_print ("Protocol: New presence from: %s\n", 
+        DEBUG_MSG (("Protocol: New presence from: %s", 
 		   lm_message_node_get_attribute (m->node, "from")));
 
 	if (gossip_jabber_chatrooms_get_jid_is_chatroom (priv->chatrooms,
@@ -2200,7 +2206,7 @@ jabber_subscription_message_handler (LmMessageHandler  *handler,
 	lm_message_handler_invalidate (handler);
 	
 	/* send subscribed to them */
-	d(g_print ("Protocol: Sending subscribed message to new service:'%s'\n", to));
+	DEBUG_MSG (("Protocol: Sending subscribed message to new service:'%s'", to));
 	new_message = lm_message_new_with_sub_type (to,
 						    LM_MESSAGE_TYPE_PRESENCE,
 						    LM_MESSAGE_SUB_TYPE_SUBSCRIBED);
@@ -2248,7 +2254,7 @@ jabber_request_version (GossipJabber *jabber,
 	from = lm_message_node_get_attribute (m->node, "from");
 	id = lm_message_node_get_attribute (m->node, "id");
 
-	d(g_print ("Protocol: Version request from:'%s'\n", from));
+	DEBUG_MSG (("Protocol: Version request from:'%s'", from));
 
 	r = lm_message_new_with_sub_type (from,
 					  LM_MESSAGE_TYPE_IQ,
@@ -2752,13 +2758,13 @@ gossip_jabber_get_contact_from_jid (GossipJabber *jabber,
 	priv = GET_PRIV (jabber);
 
 	jid = gossip_jid_new (jid_str);
-	d(g_print ("Protocol: Get contact: %s\n", gossip_jid_get_full (jid)));
+	DEBUG_MSG (("Protocol: Get contact: %s", gossip_jid_get_full (jid)));
 
 	contact = g_hash_table_lookup (priv->contacts, 
 				       gossip_jid_get_without_resource (jid));
 
 	if (!contact) {
-		d(g_print ("Protocol: New contact\n"));
+		DEBUG_MSG (("Protocol: New contact"));
 		contact = gossip_contact_new (GOSSIP_CONTACT_TYPE_TEMPORARY,
 					      priv->account);
 		gossip_contact_set_id (contact, 
