@@ -39,7 +39,6 @@
 
 #define STRING_EMPTY(x) ((x) == NULL || (x)[0] == '\0')
 
-
 typedef struct {
 	GtkWidget *window;
 
@@ -48,9 +47,11 @@ typedef struct {
 
 	GtkWidget *button_remove;
 	GtkWidget *button_connect;
+	GtkWidget *button_forget;
 
 	GtkWidget *entry_name;
 	GtkWidget *entry_id;
+	GtkWidget *entry_resource;
 	GtkWidget *entry_server;
 	GtkWidget *entry_password;
 	GtkWidget *entry_port;
@@ -63,13 +64,11 @@ typedef struct {
 
 } GossipAccountsDialog;
 
-
 typedef struct {
 	GossipAccount *account;
 	GtkComboBox   *combobox;
 } SetAccountData;
 
-
 static void           accounts_dialog_setup                     (GossipAccountsDialog  *dialog);
 static void           accounts_dialog_update_connect_button     (GossipAccountsDialog  *dialog);
 static void           accounts_dialog_update_account            (GossipAccountsDialog  *dialog,
@@ -130,6 +129,8 @@ static void           accounts_dialog_button_add_clicked_cb     (GtkWidget
 								 GossipAccountsDialog  *dialog);
 static void           accounts_dialog_button_remove_clicked_cb  (GtkWidget             *button,
 								 GossipAccountsDialog  *dialog);
+static void           accounts_dialog_button_forget_clicked_cb  (GtkWidget             *button,
+								 GossipAccountsDialog  *dialog);
 static void           accounts_dialog_button_close_clicked_cb   (GtkWidget             *button,
 								 GossipAccountsDialog  *dialog);
 static gboolean       accounts_dialog_foreach                   (GtkTreeModel          *model,
@@ -139,7 +140,6 @@ static gboolean       accounts_dialog_foreach                   (GtkTreeModel
 static void           accounts_dialog_destroy_cb                (GtkWidget             *widget,
 								 GossipAccountsDialog  *dialog);
 
-
 enum {
 	COL_NAME,
 	COL_EDITABLE,
@@ -150,7 +150,6 @@ enum {
 	COL_COUNT
 };
 
-
 static void
 accounts_dialog_setup (GossipAccountsDialog *dialog)
 {
@@ -258,6 +257,7 @@ accounts_dialog_update_account (GossipAccountsDialog *dialog,
 	gchar          *port_str; 
 	const gchar    *id;
 
+	const gchar    *resource;
 	const gchar    *server;
 	const gchar    *password;
 
@@ -294,6 +294,9 @@ accounts_dialog_update_account (GossipAccountsDialog *dialog,
 	password = gossip_account_get_password (account);
 	gtk_entry_set_text (GTK_ENTRY (dialog->entry_password), password ? password : "");
 
+	resource = gossip_account_get_resource (account);
+	gtk_entry_set_text (GTK_ENTRY (dialog->entry_resource), resource ? resource : "");
+
 	server = gossip_account_get_server (account);
 	gtk_entry_set_text (GTK_ENTRY (dialog->entry_server), server ? server : "");
 
@@ -301,6 +304,8 @@ accounts_dialog_update_account (GossipAccountsDialog *dialog,
 	gtk_entry_set_text (GTK_ENTRY (dialog->entry_port), port_str);
 	g_free (port_str);
 
+	gtk_widget_set_sensitive (dialog->button_forget, ! STRING_EMPTY (password));
+
 	/* unblock signals */
 	accounts_dialog_block_widgets (dialog, FALSE);
 }
@@ -320,6 +325,9 @@ accounts_dialog_block_widgets (GossipAccountsDialog *dialog,
 		g_signal_handlers_block_by_func (dialog->entry_password,
 						 accounts_dialog_entry_changed_cb, 
 						 dialog);
+		g_signal_handlers_block_by_func (dialog->entry_resource,
+						 accounts_dialog_entry_changed_cb, 
+						 dialog);
 		g_signal_handlers_block_by_func (dialog->entry_server,
 						 accounts_dialog_entry_changed_cb, 
 						 dialog);
@@ -346,6 +354,9 @@ accounts_dialog_block_widgets (GossipAccountsDialog *dialog,
 		g_signal_handlers_unblock_by_func (dialog->entry_password,
 						   accounts_dialog_entry_changed_cb, 
 						   dialog);
+		g_signal_handlers_unblock_by_func (dialog->entry_resource,
+						   accounts_dialog_entry_changed_cb, 
+						   dialog);
 		g_signal_handlers_unblock_by_func (dialog->entry_server,
 						   accounts_dialog_entry_changed_cb, 
 						   dialog);
@@ -390,6 +401,10 @@ accounts_dialog_save (GossipAccountsDialog *dialog,
 	str = gtk_entry_get_text (GTK_ENTRY (dialog->entry_password));
 	gossip_account_set_password (account, str);
 
+	/* set resource */
+	str = gtk_entry_get_text (GTK_ENTRY (dialog->entry_resource));
+	gossip_account_set_resource (account, str);
+
 	/* set server */
 	str = gtk_entry_get_text (GTK_ENTRY (dialog->entry_server));
 	gossip_account_set_server (account, str);
@@ -437,7 +452,8 @@ accounts_dialog_model_setup (GossipAccountsDialog *dialog)
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
 	g_signal_connect (selection, "changed", 
-			  G_CALLBACK (accounts_dialog_model_selection_changed), dialog);
+			  G_CALLBACK (accounts_dialog_model_selection_changed), 
+			  dialog);
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store), 
 					      COL_NAME, GTK_SORT_ASCENDING);
@@ -831,6 +847,7 @@ accounts_dialog_entry_focus_cb (GtkWidget            *widget,
 
 	if (widget == dialog->entry_name ||
 	    widget == dialog->entry_password ||
+	    widget == dialog->entry_resource ||
 	    widget == dialog->entry_server) {
 		const gchar *str;
 
@@ -840,6 +857,8 @@ accounts_dialog_entry_focus_cb (GtkWidget            *widget,
 				str = gossip_account_get_name (account);
 			} else if (widget == dialog->entry_password) {
 				str = gossip_account_get_password (account);
+			} else if (widget == dialog->entry_resource) {
+				str = gossip_account_get_resource (account);
 			} else if (widget == dialog->entry_server) {
 				str = gossip_account_get_server (account);
 			}
@@ -904,6 +923,11 @@ accounts_dialog_entry_changed_cb (GtkWidget            *widget,
 
 			return;
 		}
+	} else if (widget == dialog->entry_password) {
+		const gchar *str;
+
+		str = gtk_entry_get_text (GTK_ENTRY (widget));
+		gtk_widget_set_sensitive (dialog->button_forget, ! STRING_EMPTY (str));
 	}
 
 	/* save */
@@ -989,6 +1013,16 @@ accounts_dialog_protocol_connected_cb (GossipSession        *session,
 	GtkTreeModel     *model;
 	GtkTreeIter       iter;
 	gboolean          ok;
+	GossipAccount    *selected_account;
+
+	selected_account = accounts_dialog_model_get_selected (dialog);
+	if (selected_account) {
+		if (gossip_account_equal (selected_account, account)) {
+			gtk_widget_set_sensitive (dialog->button_remove, FALSE);
+		}
+		
+		g_object_unref (selected_account);
+	}
 
 	view = GTK_TREE_VIEW (dialog->treeview);
 	selection = gtk_tree_view_get_selection (view);
@@ -1036,6 +1070,17 @@ accounts_dialog_protocol_disconnected_cb (GossipSession        *session,
 	GtkTreeModel     *model;
 	GtkTreeIter       iter;
 	gboolean          ok;
+	
+	GossipAccount    *selected_account;
+
+	selected_account = accounts_dialog_model_get_selected (dialog);
+	if (selected_account) {
+		if (gossip_account_equal (selected_account, account)) {
+			gtk_widget_set_sensitive (dialog->button_remove, TRUE);
+		}
+		
+		g_object_unref (selected_account);
+	}
 
 	view = GTK_TREE_VIEW (dialog->treeview);
 	selection = gtk_tree_view_get_selection (view);
@@ -1081,7 +1126,7 @@ accounts_dialog_button_add_clicked_cb (GtkWidget            *button,
 
 static void
 accounts_dialog_button_remove_clicked_cb (GtkWidget            *button,
-					  GossipAccountsDialog *window)
+					  GossipAccountsDialog *dialog)
 {
 	GossipSession        *session;
 	GossipAccountManager *manager;
@@ -1090,7 +1135,7 @@ accounts_dialog_button_remove_clicked_cb (GtkWidget            *button,
 	session = gossip_app_get_session ();
  	manager = gossip_session_get_account_manager (session);
 
-	account = accounts_dialog_model_get_selected (window);
+	account = accounts_dialog_model_get_selected (dialog);
 
 	gossip_account_manager_remove (manager, account);
 	gossip_account_manager_store (manager);
@@ -1099,8 +1144,8 @@ accounts_dialog_button_remove_clicked_cb (GtkWidget            *button,
 }
 
 static void
-accounts_dialog_button_connect_clicked_cb (GtkWidget            *button,
-					   GossipAccountsDialog *window)
+accounts_dialog_button_forget_clicked_cb (GtkWidget            *button,
+					  GossipAccountsDialog *dialog)
 {
 	GossipSession        *session;
 	GossipAccountManager *manager;
@@ -1109,7 +1154,28 @@ accounts_dialog_button_connect_clicked_cb (GtkWidget            *button,
 	session = gossip_app_get_session ();
  	manager = gossip_session_get_account_manager (session);
 
-	account = accounts_dialog_model_get_selected (window);
+	account = accounts_dialog_model_get_selected (dialog);
+
+	gossip_account_set_password (account, "");
+	gossip_account_manager_store (manager);
+
+	g_object_unref (account);
+
+	gtk_entry_set_text (GTK_ENTRY (dialog->entry_password), "");
+}
+
+static void
+accounts_dialog_button_connect_clicked_cb (GtkWidget            *button,
+					   GossipAccountsDialog *dialog)
+{
+	GossipSession        *session;
+	GossipAccountManager *manager;
+	GossipAccount        *account;
+
+	session = gossip_app_get_session ();
+ 	manager = gossip_session_get_account_manager (session);
+
+	account = accounts_dialog_model_get_selected (dialog);
 
 	if (gossip_session_is_connected (session, account)) {
 		gossip_session_disconnect (session, account);
@@ -1199,7 +1265,7 @@ gossip_accounts_dialog_show (GossipAccount *account)
 	GladeXML                    *glade;
 	GtkSizeGroup                *size_group;
 	GtkWidget                   *label_name, *label_id, *label_password;
-	GtkWidget                   *label_server, *label_port; 
+	GtkWidget                   *label_server, *label_resource, *label_port; 
 	GtkWidget                   *bbox, *button_close;
 
 	if (dialog) {
@@ -1219,10 +1285,12 @@ gossip_accounts_dialog_show (GossipAccount *account)
 				       "label_name", &label_name,
 				       "label_id", &label_id,
 				       "label_password", &label_password,
+				       "label_resource", &label_resource,
 				       "label_server", &label_server,
 				       "label_port", &label_port,
 				       "entry_name", &dialog->entry_name,
 				       "entry_id", &dialog->entry_id,
+				       "entry_resource", &dialog->entry_resource,
 				       "entry_server", &dialog->entry_server,
 				       "entry_password", &dialog->entry_password,
 				       "entry_port", &dialog->entry_port,
@@ -1231,6 +1299,7 @@ gossip_accounts_dialog_show (GossipAccount *account)
 				       "checkbutton_connect", &dialog->checkbutton_connect,
 				       "button_remove", &dialog->button_remove,
 				       "button_connect", &dialog->button_connect,
+				       "button_forget", &dialog->button_forget,
 				       "button_close", &button_close,
 				       NULL);
 
@@ -1240,11 +1309,13 @@ gossip_accounts_dialog_show (GossipAccount *account)
 			      "entry_name", "changed", accounts_dialog_entry_changed_cb,
 			      "entry_id", "changed", accounts_dialog_entry_changed_cb,
 			      "entry_password", "changed", accounts_dialog_entry_changed_cb,
+			      "entry_resource", "changed", accounts_dialog_entry_changed_cb,
 			      "entry_server", "changed", accounts_dialog_entry_changed_cb,
 			      "entry_port", "changed", accounts_dialog_entry_changed_cb,
 			      "entry_name", "focus-out-event", accounts_dialog_entry_focus_cb,
 			      "entry_id", "focus-out-event", accounts_dialog_entry_focus_cb,
 			      "entry_password", "focus-out-event", accounts_dialog_entry_focus_cb,
+			      "entry_resource", "focus-out-event", accounts_dialog_entry_focus_cb,
 			      "entry_server", "focus-out-event", accounts_dialog_entry_focus_cb,
 			      "entry_port", "focus-out-event", accounts_dialog_entry_focus_cb,
 			      "entry_port", "insert_text", accounts_dialog_entry_port_insert_text_cb,
@@ -1253,6 +1324,7 @@ gossip_accounts_dialog_show (GossipAccount *account)
 			      "checkbutton_connect", "toggled", accounts_dialog_checkbutton_toggled_cb,
 			      "button_add", "clicked", accounts_dialog_button_add_clicked_cb,
 			      "button_remove", "clicked", accounts_dialog_button_remove_clicked_cb,
+			      "button_forget", "clicked", accounts_dialog_button_forget_clicked_cb,
 			      "button_connect", "clicked", accounts_dialog_button_connect_clicked_cb,
 			      "button_close", "clicked", accounts_dialog_button_close_clicked_cb,
 			      NULL);
@@ -1294,6 +1366,7 @@ gossip_accounts_dialog_show (GossipAccount *account)
 
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
+	gtk_size_group_add_widget (size_group, label_resource);
 	gtk_size_group_add_widget (size_group, label_server);
 	gtk_size_group_add_widget (size_group, label_port);
 
